! This file is part of HiggsBounds
!  -KW
!****************************************************** 
module theory_XS_SM_functions 
!****************************************************** 
 ! XS_qq_HW_SM,XS_qq_HZ_SM,XS_gg_H_SM,XS_bb_H_SM,XS_vbf:_H_SM
 ! in units of fb
 ! functions are fitted to data 
 ! downloaded from http://maltoni.home.cern.ch/maltoni/TeV4LHC/bbh-tev_ed.dat
 ! on Thursday 10th April 2008
 ! data has range 100 to 300 GeV
 !
 ! functions XS_bg_Hb_SM,XS_bg_Hb_c1_SM,XS_bg_Hb_c2_SM were generated by Oliver Brein
 
 double precision :: XS_SM_functions_xmin=60.0D0
 double precision :: XS_SM_functions_xmax=335.0D0
! this must be narrower than range of 
!XS_bg_Hb_SM,XS_bg_Hb_c1_SM,XS_bg_Hb_c2_SM ([10:400])
!theory_tevSfunctions (currently [50:400])

 contains 

!files from OB (his calculations)
!only change I made:
! end->end function
#include "cs-ratios_sigma-bg-Hb/Tevatron.sigma_bg_Hb.h"
#include "cs-ratios_sigma-bg-Hb/Tevatron.sigma_bg_Hb.ptmin15.etamax2.h"
#include "cs-ratios_sigma-bg-Hb/Tevatron.sigma_bg_Hb.ptmin20.etamax2.5.h"

 !****************************************************** 
 subroutine check_range(Mh)
 !****************************************************** 
  implicit none
  double precision, intent(in) :: Mh 
 
  if(    Mh.lt.XS_SM_functions_xmin)then
   stop 'Higgs mass is below valid range for the SM cross section functions' 
  elseif(Mh.gt.XS_SM_functions_xmax)then
   stop 'Higgs mass is above valid range for the SM cross section functions'
  endif 
 end subroutine check_range

 !****************************************************** 
 function XS_bg_Hb_SM(x)
 !******************************************************
  implicit none
  double precision :: XS_bg_Hb_SM
  double precision, intent(in) :: x 

  call check_range(x)
  XS_bg_Hb_SM=1.0D3*tev_cs_bg_Hb_SM(x) !convert from pb to fb

 end function XS_bg_Hb_SM 
 !****************************************************** 
 function XS_bg_Hb_c1_SM(x)
 !******************************************************
  implicit none
  double precision :: XS_bg_Hb_c1_SM
  double precision, intent(in) :: x 

  call check_range(x)
  XS_bg_Hb_c1_SM=1.0D3*tev_cs_bg_Hb_c1_SM(x) !convert from pb to fb
  
 end function XS_bg_Hb_c1_SM 
 !****************************************************** 
 function XS_bg_Hb_c2_SM(x)
 !******************************************************
  implicit none
  double precision :: XS_bg_Hb_c2_SM
  double precision, intent(in) :: x 

  call check_range(x)
  XS_bg_Hb_c2_SM=1.0D3*tev_cs_bg_Hb_c2_SM(x) !convert from pb to fb
  
 end function XS_bg_Hb_c2_SM 
 !****************************************************** 
 function XS_qq_HW_SM(x)
 !******************************************************
  implicit none
  double precision :: XS_qq_HW_SM
  double precision, intent(in) :: x 
  double precision :: a0,a0p5,a1,a2
  
  a0 = 5.7514105496046D0
  a0p5 = -0.375021739545092D0
  a1 = 0.0049451487167627D0
  a2 = -3.77008582179264D-06
  
  call check_range(x)
  XS_qq_HW_SM=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)

 end function XS_qq_HW_SM
 !****************************************************** 
 function XS_qq_HZ_SM(x)
 !****************************************************** 
  implicit none
  double precision :: XS_qq_HZ_SM
  double precision, intent(in) :: x 
  double precision :: a0,a0p5,a1,a2
 
  a0 = 5.29935340004443D0
  a0p5 = -0.351677660532052D0
  a1 = 0.0047848452802514D0
  a2 = -3.82425969474559D-06 

  call check_range(x)
  XS_qq_HZ_SM=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)

 end function XS_qq_HZ_SM 
 !****************************************************** 
 function XS_gg_H_SM(x)
 !******************************************************
  implicit none
  double precision :: XS_gg_H_SM
  double precision, intent(in) :: x 
  double precision :: a0,a0p5,a1,a2
 
  a0 = 5.59682783597183D0
  a0p5 = -0.244216706673437D0
  a1 = 0.000365613425058581D0
  a2 = 2.66122261164927D-06  
	
  call check_range(x)
  XS_gg_H_SM=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
   
 end function XS_gg_H_SM
 !****************************************************** 
 function XS_bb_H_SM(x)
 !******************************************************
  implicit none
  double precision :: XS_bb_H_SM
  double precision, intent(in) :: x
  double precision :: a0,a0p5,a1,a2
 
  a0 = 5.41583328209568D0
  a0p5 = -0.453323023285831D0
  a1 = 0.00514220061294974D0
  a2 = -3.31488355831377D-06
	
  call check_range(x)
  XS_bb_H_SM=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
  
 end function XS_bb_H_SM 
 !****************************************************** 
 function XS_vbf_SM(x)
 !******************************************************
  implicit none
  double precision :: XS_vbf_SM
  double precision, intent(in) :: x 
  double precision :: a0,a0p5,a1,a2
 
  a0 = 3.03330688577339D0
  a0p5 = -0.061167148821396D0
  a1 = -0.00424395931917914D0
  a2 = 7.67964289500027D-08
	
  call check_range(x)
  XS_vbf_SM=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
  
 end function XS_vbf_SM
 !******************************************************
end module theory_XS_SM_functions
